@@ -1,23 +1,9 @@
 /*
- * <one line to give the library's name and an idea of what it does.>
- * Copyright (C) 2014  Vishesh Handa <me@vhanda.in>
- * Copyright (C) 2016  Christoph Cullmann <cullmann@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2016 Christoph Cullmann <cullmann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "odfextractortest.h"
 
@@ -30,20 +16,66 @@
 
 using namespace KFileMetaData;
 
+Q_DECLARE_METATYPE(Type::Type)
+
 QString OdfExtractorTest::testFilePath(const QString& fileName) const
 {
     return QLatin1String(INDEXER_TESTS_SAMPLE_FILES_PATH) + QLatin1Char('/') + fileName;
 }
 
-void OdfExtractorTest::testText()
+void OdfExtractorTest::testNoExtraction_data()
 {
+    QTest::addColumn<QString>("fileName");
+    QTest::addColumn<QVector<Type::Type>>("types");
+
+    QTest::newRow("regular text") << QStringLiteral("test.odt") << QVector<Type::Type>{Type::Document};
+    QTest::newRow("flat xml text") << QStringLiteral("test.fodt") << QVector<Type::Type>{Type::Document};
+
+    QTest::newRow("regular presentation") << QStringLiteral("test.odp") << QVector<Type::Type>{Type::Document, Type::Presentation};
+    QTest::newRow("flat xml presentation") << QStringLiteral("test.fodp") << QVector<Type::Type>{Type::Document, Type::Presentation};
+
+    QTest::newRow("regular graphic") << QStringLiteral("test.odg") << QVector<Type::Type>{Type::Document, Type::Image};
+    QTest::newRow("flat xml graphic") << QStringLiteral("test.fodg") << QVector<Type::Type>{Type::Document, Type::Image};
+}
+
+void OdfExtractorTest::testNoExtraction()
+{
+    QFETCH(QString, fileName);
+    QFETCH(QVector<Type::Type>, types);
+
     OdfExtractor plugin{this};
 
-    QString fileName = testFilePath(QStringLiteral("test.odt"));
-    QString mimeType = MimeUtils::strictMimeType(fileName, mimeDb).name();
+    const QString path = testFilePath(fileName);
+    const QString mimeType = MimeUtils::strictMimeType(path, mimeDb).name();
     QVERIFY(plugin.mimetypes().contains(mimeType));
 
-    SimpleExtractionResult result(fileName, mimeType);
+    SimpleExtractionResult result(path, mimeType, ExtractionResult::ExtractNothing);
+    plugin.extract(&result);
+
+    QCOMPARE(result.types().size(), types.size());
+    QCOMPARE(result.types(), types);
+    QCOMPARE(result.properties().size(),0);
+}
+
+void OdfExtractorTest::testText_data()
+{
+    QTest::addColumn<QString>("fileName");
+
+    QTest::newRow("regular") << QStringLiteral("test.odt");
+    QTest::newRow("flat xml") << QStringLiteral("test.fodt");
+}
+
+void OdfExtractorTest::testText()
+{
+    QFETCH(QString, fileName);
+
+    OdfExtractor plugin{this};
+
+    const QString path = testFilePath(fileName);
+    const QString mimeType = MimeUtils::strictMimeType(path, mimeDb).name();
+    QVERIFY(plugin.mimetypes().contains(mimeType));
+
+    SimpleExtractionResult result(path, mimeType);
     plugin.extract(&result);
 
     QCOMPARE(result.types().size(), 1);
@@ -76,15 +108,25 @@ void OdfExtractorTest::testTextMetaDataOnly()
     QVERIFY(result.text().isEmpty());
 }
 
+void OdfExtractorTest::testPresentation_data()
+{
+    QTest::addColumn<QString>("fileName");
+
+    QTest::newRow("regular") << QStringLiteral("test.odp");
+    QTest::newRow("flat xml") << QStringLiteral("test.fodp");
+}
+
 void OdfExtractorTest::testPresentation()
 {
+    QFETCH(QString, fileName);
+
     OdfExtractor plugin{this};
 
-    QString fileName = testFilePath(QStringLiteral("test.odp"));
-    QString mimeType = MimeUtils::strictMimeType(fileName, mimeDb).name();
+    const QString path = testFilePath(fileName);
+    const QString mimeType = MimeUtils::strictMimeType(path, mimeDb).name();
     QVERIFY(plugin.mimetypes().contains(mimeType));
 
-    SimpleExtractionResult result(fileName, mimeType);
+    SimpleExtractionResult result(path, mimeType);
     plugin.extract(&result);
 
     QCOMPARE(result.types().size(), 2);
@@ -98,6 +140,38 @@ void OdfExtractorTest::testPresentation()
     QCOMPARE(result.text(), QStringLiteral("KFileMetaData Pres "));
 }
 
+void OdfExtractorTest::testGraphic_data()
+{
+    QTest::addColumn<QString>("fileName");
+
+    QTest::newRow("regular") << QStringLiteral("test.odg");
+    QTest::newRow("flat xml") << QStringLiteral("test.fodg");
+}
+
+void OdfExtractorTest::testGraphic()
+{
+    QFETCH(QString, fileName);
+
+    OdfExtractor plugin{this};
+
+    const QString path = testFilePath(fileName);
+    const QString mimeType = MimeUtils::strictMimeType(path, mimeDb).name();
+    QVERIFY(plugin.mimetypes().contains(mimeType));
+
+    SimpleExtractionResult result(path, mimeType);
+    plugin.extract(&result);
+
+    QCOMPARE(result.types().size(), 2);
+    QCOMPARE(result.types().at(0), Type::Document);
+    QCOMPARE(result.types().at(1), Type::Image);
+
+    QVERIFY(result.properties().value(Property::Generator).toString().contains(QStringLiteral("LibreOffice")));
+    QDateTime dt(QDate(2022, 11, 8), QTime(15, 27, 0, 660));
+    QCOMPARE(result.properties().value(Property::CreationDate), QVariant(dt));
+
+    QCOMPARE(result.text(), QStringLiteral("KFileMetaData Graphic "));
+}
+
 void OdfExtractorTest::testTextMissingMetaNoCrash()
 {
     OdfExtractor plugin{this};
